@@ -156,6 +156,9 @@ def _resolve_dfs(raw_io):
     referral = dfs_request(raw_io.fd.tree_connect, raw_path[1:])
     client_config.cache_referral(referral)
     info = client_config.lookup_referral([p for p in raw_path.split("\\") if p])
+    if not info:
+        raise ObjectPathNotFound()
+
     connection_kwargs = getattr(raw_io, '_%s__kwargs' % type(raw_io).__name__, {})
 
     for target in info:
@@ -165,7 +168,7 @@ def _resolve_dfs(raw_io):
             tree, fd_path = get_smb_tree(new_path, **connection_kwargs)
 
         except SMBResponseException as link_exc:
-            log.warning("Failed to connect to DFS link target %s: %s" % (str(target), link_exc))
+            log.warning("Failed to connect to DFS link target %s: %s", str(target), link_exc)
             continue
 
         # Record the target that worked for future reference.
@@ -563,7 +566,7 @@ class SMBRawIO(io.RawIOBase):
 
         chunk_size, credit_request = _chunk_size(self.fd.connection, len(b), 'read')
 
-        print(f"Read {self._offset} - {chunk_size}")
+        log.debug("Read %d -%d.", self._offset, chunk_size)
         read_msg, recv_func = self.fd.read(self._offset, chunk_size, send=False)
         request = self.fd.connection.send(
             read_msg,
